class classificationModel : 

    def __init__(self) : 
        self.model = None
        self.std_out = None

    def load(self) : 
        self.std_out = "Hello Moom!!!"
        return self.std_out

    def predict(self) : 
        self.std_out = "How are you!"
        return self.std_out



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup (
    name = 'sangheeMODEL',
    version = '0.0.0',
    license = 'MIT',
    description = 'sanghee\'s NLP models.',
    author = 'sanghee park',
    author_email = 'parksangheeeee@naver.com',
    url = 'https://github.com/ajskdlf64/sanghee-nlp-tool',
    packages = setuptools.find_packages(),
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)